#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GLOBAL_CONFIG = exports.axiosInstance = void 0;
var commander_1 = require("commander");
var InitProject_1 = require("./commands/InitProject");
var Login_1 = require("./commands/Login");
var axios_1 = __importDefault(require("axios"));
var utils_1 = require("./utils");
var DeployProject_1 = require("./commands/DeployProject");
var UserService_1 = require("./user/UserService");
var ConfigManager_1 = require("./ConfigManager");
var Logout_1 = require("./commands/Logout");
var chalk = require('chalk');
var clear = require('clear');
var figlet = require('figlet');
var path = require('path');
exports.axiosInstance = axios_1.default.create({
    baseURL: 'https://api.upli.io'
});
exports.axiosInstance.interceptors.request.use(function (request) {
    request.headers.Cookie = "token=" + UserService_1.getToken();
    return request;
}, function (error) { return error; });
exports.axiosInstance.interceptors.response.use(function (response) { return response; }, function (error) {
    var _a, _b, _c, _d, _e;
    switch ((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) {
        case 401:
            console.log(utils_1.Colors.FgRed + "Please login with " + utils_1.Colors.FgCyan + "upli login" + utils_1.Colors.Reset);
            break;
        case 403: // dont handle this error here
            break;
        default:
            var errorMessages = (_d = (_c = (_b = error.response) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.error) === null || _d === void 0 ? void 0 : _d.message;
            utils_1.debug("Error while sending request to " + ((_e = error === null || error === void 0 ? void 0 : error.config) === null || _e === void 0 ? void 0 : _e.url));
            if (errorMessages) {
                errorMessages.forEach(function (msg) { return console.log(utils_1.Colors.FgRed + msg + utils_1.Colors.Reset); });
            }
            else {
                console.log(utils_1.Colors.FgRed + "Unknown error: " + JSON.stringify(error.response) + utils_1.Colors.Reset);
            }
    }
    return Promise.reject(error);
});
clear();
console.log(chalk.red(figlet.textSync('upli-cli', { horizontalLayout: 'full' })) + chalk.grey('https://upli.io'));
// load global config
exports.GLOBAL_CONFIG = ConfigManager_1.loadConfig(ConfigManager_1.GLOBAL_CONFIG_FILE);
if (exports.GLOBAL_CONFIG === null || exports.GLOBAL_CONFIG === void 0 ? void 0 : exports.GLOBAL_CONFIG.user) {
    UserService_1.setCurrentUser(exports.GLOBAL_CONFIG === null || exports.GLOBAL_CONFIG === void 0 ? void 0 : exports.GLOBAL_CONFIG.user);
    console.log(chalk.yellow("Currently logged in as " + UserService_1.user.username + "\n"));
}
commander_1.program
    .option('-d, --debug', 'Enable debug logging')
    .option('-a, --api <api>', 'Use custom api endpoint (for development)', function (a) { return exports.axiosInstance.defaults.baseURL = a; })
    .option('-t, --token <token>', 'Use authentication token', function (a) { return UserService_1.setToken(a); })
    .addCommand(Login_1.Login)
    .addCommand(Logout_1.Logout)
    .addCommand(InitProject_1.InitProject)
    .addCommand(DeployProject_1.DeployProject)
    .parse(process.argv);
